@@ -20,7 +20,7 @@ module OpenAI.V1.Chat.Completions
     , AudioFormat(..)
     , AudioParameters(..)
     , ResponseFormat(..)
-    , ServiceTier(..)
+    , ServiceTier
     , ReasoningEffort(..)
     , SearchContextSize(..)
     , UserLocation(..)
@@ -28,7 +28,7 @@ module OpenAI.V1.Chat.Completions
     , FinishReason(..)
     , Token(..)
     , LogProbs(..)
-    -- * Servant
+      -- * Servant
     , API
     ) where
 
@@ -207,21 +207,12 @@ data AudioParameters = AudioParameters
       deriving anyclass (FromJSON, ToJSON)
 
 -- | Specifies the latency tier to use for processing the request
-data ServiceTier = Default
-    deriving stock (Generic, Show)
-
-serviceOptions :: Options
-serviceOptions = aesonOptions{ tagSingleConstructors = True }
-
-instance FromJSON ServiceTier where
-    parseJSON = genericParseJSON serviceOptions
-
-instance ToJSON ServiceTier where
-    toJSON = genericToJSON serviceOptions
+type ServiceTier = Text
 
 -- | Constrains effort on reasoning for reasoning models
 data ReasoningEffort
-    = ReasoningEffort_Low
+    = ReasoningEffort_Minimal
+    | ReasoningEffort_Low
     | ReasoningEffort_Medium
     | ReasoningEffort_High
     deriving stock (Generic, Show)
